

Usero
===============
This package will help you to manage userdata. Create new users with username and passwords and manage their datatables.
All passwords will be hashed with MD5 method.

Installing
============

.. code-block:: bash

    pip install Usero

Usage
=====

.. code-block:: bash

    >>> from src import usero
